@@ -6,7 +6,7 @@
 # * Unit test script for misc.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 2016 Nicolas Roche
+# Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,6 +31,12 @@ set -e
 TEST=$(basename $0)
 TEST=${TEST%.sh}
 
+# add cache.htaccess file
+mkdir -p $GITCLT/mdtx1-coll1/apache2
+cat > $GITCLT/mdtx1-coll1/apache2/cache.htaccess <<EOF
+Content from git
+EOF
+
 # run the unit test
 client/ut$TEST >client/$TEST.out 2>&1
 
