@@ -6,7 +6,7 @@
  * (please look at utconfTree.c for some explanation on the topology)
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -422,7 +422,7 @@ int createExempleExtractTree(Collection* coll)
   sprintf(dateString, "%04i-%02i-%02i,%02i:%02i:%02i", 
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec);
-  if (!(container = coll->extractTree->incoming)) goto error;
+  if (!(container = coll->extractTree->inc)) goto error;
   if (!(asso = addFromAsso(coll, iso1, container, dateString))) goto error;
   if (!(asso = addFromAsso(coll, iso2, container, "1994-01-01,00:00:00"))) 
     goto error;
@@ -430,6 +430,15 @@ int createExempleExtractTree(Collection* coll)
   // this one should be automatically removed
   if (!(asso = addFromAsso(coll, logo, container, dateString))) goto error;
 
+  // IMG
+  if (!(container = coll->extractTree->img)) goto error;
+  if (!(asso = addFromAsso(coll, gzip, container,
+			   "here/logo.gz"))) goto error;
+
+  // this one should be automatically removed*
+  if (!(asso = addFromAsso(coll, logo, container,
+			   "here/logo.png"))) goto error;  
+
   return TRUE;
  error:
   logMemory(LOG_ERR, 
@@ -730,6 +739,7 @@ createExempleServerTree(Collection* coll)
   if (!(coll->serverTree)) goto error;
   if (!(coll->serverTree->master = addServer(coll, serverId[1]))) 
     goto error;
+  strncpy(coll->serverTree->dnsHost, "dns_name.org", MAX_SIZE_HOST);
   strncpy(coll->serverTree->aesKey, "1234567890abcdef", MAX_SIZE_AES);
 
   for (i=0; i<3; ++i) {
