@@ -5,7 +5,7 @@
  * HTML generator
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -222,14 +222,14 @@ main(int argc, char** argv)
   // export mdtx environment
   if (!setEnv(programName, &env)) goto optError;
 
-  /************************************************************************/
+  /**********************************************************************/
   if (!(fd = fopen(htmlPath, "w"))) {
     logMain(LOG_ERR, "fopen fails: %s", strerror(errno));
     goto error;
   }
 
   if (!htmlMainHead(fd, "Main")) goto error;
-  if (!htmlLeftPageHead(fd, "index")) 
+  if (!htmlLeftPageHead(fd, "index", 0, 0)) 
     goto error;
   if (!htmlLeftPageMiddle(fd)) goto error;
   if (!htmlLeftPageTail(fd)) goto error;
@@ -241,7 +241,7 @@ main(int argc, char** argv)
     logMain(LOG_ERR, "fclose fails: %s", strerror(errno));
     goto error;
   }
-  /************************************************************************/
+  /**********************************************************************/
 
   rc = TRUE;
  error:
