@@ -7,7 +7,7 @@
 # * repositories.
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 2016 Nicolas Roche
+# Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -324,17 +324,14 @@ function GIT_coll_import()
 	done
 	install -o $1 -g $1 -m 660 /dev/null readme.html
 
-	for t in home index score cgi; do
+	for t in home cache index score cgi; do
 	    install -o $1 -g $1 -m 660 $MISC/$t.htaccess apache2/
-
-	    # adapt them
-	    sed apache2/$t.htaccess -i \
-		-e "s!MEDIATEX/!$MEDIATEX/!" \
-		-e "s!MDTX-COLL!$1!" \
-		-e "s!/MDTX/!/$MDTX/!" \
-		-e "s!HOMES!$HOMES!"
 	done
-
+	
+	# adapt home.htaccess
+	sed apache2/home.htaccess -i \
+	    -e "s!MDTX-COLL!$1!" \
+	    
 	cat > .gitignore <<EOF
 *NNN.txt
 EOF
