@@ -5,7 +5,7 @@
  * HTML catalog serializer
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -1317,7 +1317,8 @@ serializeHtmlIndexHeader(Collection* coll)
   }  
 
   if (!htmlMainHead(fd, "Index")) goto error;
-  if (!htmlLeftPageHead(fd, "index")) goto error;
+  if (!htmlLeftPageHead(fd, "index", 0, coll->serverTree->dnsUrl))
+    goto error;
 
   htmlPOpen(fd);
   getDocListUri(url, "<!--#echo var='HOME' -->/index", 1);
