@@ -5,7 +5,7 @@
 * HTML serializer common fonctions
 
 MediaTex is an Electronic Records Management System
-Copyright (C) 2014 2015 2016 Nicolas Roche
+Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -129,9 +129,9 @@ int getRelativeUri(char* buf, char* prefix, char* suffix)
 }
 
 /*=======================================================================
- * Function   : getArchiveHeaderUri
+ * Function   : getArchiveUri1
  * Description: Get relative path to archive page
- * Synopsis   : int getArchiveHeaderUri(char* buf, char* path, int id) 
+ * Synopsis   : int getArchiveUri1(char* buf, char* path, int id) 
  *              char* path = path to use as prefix
  *              int id = number use to compute page location
  * Output     : char* buf = the Uri
@@ -151,7 +151,7 @@ int getArchiveUri1(char* buf, char* path, int id)
 /*=======================================================================
  * Function   : getArchiveUri2
  * Description: Get relative path to an archive directory
- * Synopsis   : int getContentDir(char* buf, char* path, int id) 
+ * Synopsis   : int getArchiveUri2(char* buf, char* path, int id) 
  *              char* path = path to use as prefix
  *              int id = number use to compute page location
  * Output     : char* buf = the Uri
@@ -489,8 +489,15 @@ serializeHtmlCacheHeader(Collection* coll)
   }  
 
   if (!htmlMainHead(fd, _("Cache"))) goto error;
-  if (!htmlLeftPageHead(fd, "cache")) goto error;
+  if (!htmlLeftPageHead(fd, "cache", 0, self->dnsUrl)) goto error;
 
+  if (*self->dnsHost) {
+    strcpy(url, self->dnsUrl);
+    strcpy(url + strlen(url), "/cache"); 
+    htmlLink(fd, 0, url, self->dnsHost);
+    fprintf(fd, "&nbsp;:\n");
+  }
+  
   // server links
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
@@ -571,7 +578,8 @@ serializeHtmlCgiHeader(Collection* coll)
 
   if (!htmlMainHeadBasic(fd, _("Cache"), localhost->url))
     goto error;
-  if (!htmlLeftPageHeadBasic(fd, "cache", localhost->url))
+  if (!htmlLeftPageHeadBasic(fd, "cache", localhost->url,
+			     self->dnsUrl?self->dnsUrl:localhost->url))
     goto error;
 
   // upload link
@@ -654,7 +662,8 @@ serializeHtmlGitHeader(Collection* coll)
 
   if (!htmlMainHeadBasic(fd, _("Version"), localhost->url))
     goto error;
-  if (!htmlLeftPageHeadBasic(fd, "cgi/cgit.cgi/.git/", localhost->url))
+  if (!htmlLeftPageHead(fd, "cgi/cgit.cgi/.git/", localhost->url,
+			     self->dnsUrl?self->dnsUrl:localhost->url))
     goto error;
 
   if (!isEmptyRing(self->servers)) {
@@ -758,37 +767,53 @@ serializeHtmlCacheHtaccess(Collection* coll)
 { 
   int rc = TRUE;
   ServerTree* self = 0;
-  char* path = 0;
-  FILE* fd = stdout; 
-
+  char* pathIn = 0;
+  char* pathOut = 0;
+  FILE* fdIn = 0;
+  FILE* fdOut = stdout;
+  char buffer[256];
+  int len = 0;
+ 
   if (!(self = coll->serverTree)) goto error;
-  if (!(path = createString(coll->cacheDir))) goto error;
-  if (!(path = catString(path, "/.htaccess"))) goto error;
-  logMain(LOG_DEBUG, "serialize %s", path);
-  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+  if (!(pathIn = createString(coll->gitDir))) goto error;
+  if (!(pathIn = catString(pathIn, "/apache2/cache.htaccess"))) goto error;
+  if (!(pathOut = createString(coll->cacheDir))) goto error;
+  if (!(pathOut = catString(pathOut, "/.htaccess"))) goto error;
+  logMain(LOG_DEBUG, "serialize %s", pathOut);
+
+  if (!(fdIn = fopen(pathIn, "r"))) {
+    logMisc(LOG_ERR, "fopen %s fails: %s", pathIn, strerror(errno));
+    goto error;
+  }
+  
+  if (!env.dryRun && !(fdOut = fopen(pathOut, "w"))) {
+    logMain(LOG_ERR, "fopen %s fails: %s", pathOut, strerror(errno)); 
     goto error;
   }  
-
-  if (!fprintf(fd,
+  
+  if (!fprintf(fdOut,
 	       "# fancy index for cache\n"
 	       "Options +Indexes\n"
 	       "SetEnv HOME /~%s\n"
 	       "HeaderName"
 	       " /mediatex/%s/home/%s/public_html/cacheHeader.shtml\n"
 	       "ReadmeName"
-	       " /mediatex/%s/home/%s/public_html/footer.html\n"
-	       "\n"
-	       "# login/password\n"
-	       "Require env NO_AUTH\n"
-	       "Require group cache\n",
+	       " /mediatex/%s/home/%s/public_html/footer.html\n\n"
+	       "# bellow comes from ~%s/git/apache2/cache.htaccess\n\n",
 	       coll->user,
 	       env.confLabel, coll->user,
-	       env.confLabel, coll->user))
+	       env.confLabel, coll->user,
+	       coll->user))
       goto error;
 
+  // concat user's cache.htaccess content
+  while ((len = fread(buffer, 1, 256, fdIn)) > 0) {
+    fwrite(buffer, 1, len, fdOut);
+  }
+  
+  fclose(fdIn);
   if (!env.dryRun) {
-    fclose(fd);
+    fclose(fdOut);
   } else {
     fflush(stdout);
   }
@@ -797,7 +822,8 @@ serializeHtmlCacheHtaccess(Collection* coll)
   if (!rc) {
     logMain(LOG_ERR, "serializeHtmlCacheHtaccess fails");
   }
-  path = destroyString(path);
+  pathOut = destroyString(pathOut);
+  pathIn = destroyString(pathIn);
   return rc;
 }
 
