@@ -5,7 +5,7 @@
  * HTML extraction catalog serializer
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -1070,7 +1070,7 @@ serializeHtmsScoreIndex(Collection* coll)
   htmlUlClose(fd);
   htmlPClose(fd);
 
-    // score parameter of the collection
+  // score parameter of the collection
   htmlPOpen(fd);
   if (!fprintf(fd, _("\nSelf-ingestion parameters:\n"))) goto error;
   htmlUlOpen(fd);
@@ -1160,7 +1160,7 @@ serializeHtmlScoreHeader(Collection* coll)
   }  
 
   if (!htmlMainHead(fd, _("Score"))) goto error;
-  if (!htmlLeftPageHead(fd, _("score"))) goto error;
+  if (!htmlLeftPageHead(fd, _("score"), 0, self->dnsUrl)) goto error;
 
   // global score
   if (!fprintf(fd, "(%.2f)\n", coll->extractTree->score)) goto error;
