@@ -6,7 +6,7 @@
  * Manage upload
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -122,7 +122,7 @@ uploadExtract(Collection* upload, char* path)
 
   // assert there is no INC content  
   if (!(self = upload->extractTree)) goto error;
-  if (avl_count(self->incoming->childs) > 0) {
+  if (avl_count(self->inc->childs) > 0) {
     logMain(LOG_ERR, "unexpected incoming rules on upload");
     rc = FALSE;
   }
@@ -140,13 +140,13 @@ uploadExtract(Collection* upload, char* path)
  * Function   : uploadContent
  * Description: add uploaded content file to extract metadata
  * Synopsis   : static Archive* uploadContent(
- *                                        Collection* upload, char* path)
+ *                               Collection* upload, UploadFile* upFile)
  * Input      : Collection* upload: collection used to parse upload
  *              char* path: input file to upload
  * Output     : Archive object on success ; NULL on error
  =======================================================================*/
 static Archive* 
-uploadContent(Collection* upload, char* path)
+uploadContent(Collection* upload, UploadFile* upFile)
 { 
   Archive* rc = 0;
   struct stat statBuffer;
@@ -156,9 +156,13 @@ uploadContent(Collection* upload, char* path)
   struct tm date;
   char dateString[32];
   Container* container = 0;
+  char* path = 0;
+  char* target = 0;
+  char* ptr = 0;
 
   logMain(LOG_DEBUG, "uploadContent");
   checkCollection(upload);
+  path = upFile->source;
   checkLabel(path);
 
   if (!upload->extractTree) {
@@ -193,17 +197,34 @@ uploadContent(Collection* upload, char* path)
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec);
 
-  if (!(container = upload->extractTree->incoming)) goto error;
+  if (!(container = upload->extractTree->inc)) goto error;
   if (!(addFromAsso(upload, archive, container, dateString))) 
     goto error;
 
+  // add image extraction rule
+  if (upFile->target) {
+    if (!(target = createString(upFile->target))) goto error;
+    
+    // if target is a directory
+    if (target[strlen(target)-1] == '/') {
+
+      // concatcat the filename
+      for (ptr = path+strlen(path)-1; ptr > path && *ptr != '/'; --ptr);
+      if (!(target = catString(target, ptr+1))) goto error;
+    }
+    
+    if (!(container = upload->extractTree->img)) goto error;
+    if (!(addFromAsso(upload, archive, container, target)))
+      goto error;
+  }
+  
   rc = archive;
   archive = 0;
  error:
   if (!rc) {
     logMain(LOG_ERR, "uploadExtract fails");
   }
-  if (archive) delArchive(upload, archive);
+  if (target) destroyString(target);
   return rc;
 }
 
@@ -498,7 +519,7 @@ mdtxUpload(char* label, char* catalog, char* extract, RG* upFiles)
   if (extract && !uploadExtract(upload, extract)) goto error;
   if (!isEmptyRing(upFiles)) {
     while ((upFile = rgNext(upFiles))) {
-      if (!(upFile->archive = uploadContent(upload, upFile->source)))
+      if (!(upFile->archive = uploadContent(upload, upFile)))
 	goto error;
     }
   }
