@@ -5,7 +5,7 @@
  * Compute scores based on extraction rules
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -153,8 +153,9 @@ computeContainer(Collection* coll, Container* self, int depth)
 
   checkContainer(self);
   if (self->score != -1) goto quit; // already computed
-  if (self->type == INC) {
-    logCommon(LOG_ERR, "internal error: INC container not expected");
+  if (self->type == INC || self->type == IMG) {
+    logCommon(LOG_ERR, "internal error: %s container not expected",
+	      strEType(self->type));
     goto error;
   }
 
@@ -245,6 +246,7 @@ computeArchive(Collection* coll, Archive* self, int depth)
   self->incInherency = TRUE;
   rgRewind(self->fromContainers);
   while ((asso = rgNext(self->fromContainers))) {
+    if (asso->container->type == IMG) continue;
     if (!computeContainer(coll, asso->container, depth+1)) goto error;
     self->incInherency &= asso->container->incInherency;
     if (self->extractScore < asso->container->score) {
