@@ -5,7 +5,7 @@
  * Manage servers.txt upgrade from mediatex.conf and supports.txt
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -199,12 +199,6 @@ scoreSupport(Support* supp, ScoreParam *p)
   // check support validity
   ttl = (isSupportFile(supp))?conf->fileTTL:conf->checkTTL;
   laps = now - supp->lastCheck;
-  if (laps > ttl) {
-    logCommon(LOG_WARNING, "\"%s\" support have expired since %d days",
-	      supp->name, laps/(60*60*24));
-    // score = 0: unchecked support for too many time (may be broken)
-    goto end;
-  }
 
   // static score for support file
   if (isSupportFile(supp)) {
@@ -223,6 +217,13 @@ scoreSupport(Support* supp, ScoreParam *p)
     goto end;
   }
   
+  if (laps > ttl) {
+    logCommon(LOG_WARNING, "\"%s\" support have expired since %d days",
+	      supp->name, laps/(60*60*24));
+    // score = 0: unchecked support for too many time (may be broken)
+    goto end;
+  }
+  
   // compute a support score base on its age
   laps = now - supp->firstSeen;
 
@@ -280,6 +281,7 @@ scoreLocalImages(Collection* coll)
   Image* image2 = 0;
   Image* image3 = 0;
   int nbSupp = 0;
+  RGIT* curr = 0;
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "scores for %s collection", coll->label);
@@ -289,8 +291,8 @@ scoreLocalImages(Collection* coll)
   serverTree = coll->serverTree;
 
   // for each support names:
-  rgRewind(coll->supports);
-  while ((supp = rgNext(coll->supports))) {
+  curr = 0;
+  while ((supp = rgNext_r(coll->supports, &curr))) {
  
     // compute score on support (using collection's parameters)
     if (!scoreSupport(supp, &serverTree->scoreParam)) goto error;
@@ -515,6 +517,7 @@ int
 computeUrls(Collection* coll)
 {
   int rc = FALSE;
+  ServerTree* self = 0;
   Server* server = 0;
   RGIT* curr = 0;
   char url[512];
@@ -522,24 +525,51 @@ computeUrls(Collection* coll)
   checkCollection(coll);
   logCommon(LOG_DEBUG, "computeUrls %s", coll->label);
 
-  while ((server = rgNext_r(coll->serverTree->servers, &curr))) {
+  self = coll->serverTree;
+  
+  while ((server = rgNext_r(self->servers, &curr))) {
     
     // add port into the url if not the default one
-    if ((coll->serverTree->doHttps && server->wwwPort == 443) ||
-	(!coll->serverTree->doHttps && server->wwwPort == 80)) {
+    if ((self->doHttps && server->wwwPort == 443) ||
+	(!self->doHttps && server->wwwPort == 80)) {
       if (sprintf(url, "http%s://%s/~%s",
-		  coll->serverTree->doHttps?"s":"",
+		  self->doHttps?"s":"",
 		  server->host, server->user) <= 0) goto error;
     }
     else {
       if (sprintf(url, "http%s://%s:%i/~%s",
-		  coll->serverTree->doHttps?"s":"",
+		  self->doHttps?"s":"",
 		  server->host, server->wwwPort, server->user) <= 0)
 	goto error;
       
     }
+
+    server->url = destroyString(server->url);
     if (!(server->url = createString(url))) goto error;
   }
+
+  // do the same for dns entry
+  //  (all hosts must use the same ports and mdtx's label)
+  if (*self->dnsHost) {
+
+    // add port into the url if not the default one
+    if ((self->doHttps && self->master->wwwPort == 443) ||
+	(!self->doHttps && self->master->wwwPort == 80)) {
+      if (sprintf(url, "http%s://%s/~%s",
+		  self->doHttps?"s":"",
+		  self->dnsHost, self->master->user) <= 0) goto error;
+    }
+    else {
+      if (sprintf(url, "http%s://%s:%i/~%s",
+		  self->doHttps?"s":"", self->dnsHost,
+		  self->master->wwwPort, self->master->user) <= 0)
+	goto error;
+      
+    }
+    
+    self->dnsUrl = destroyString(self->dnsUrl);
+    if (!(self->dnsUrl = createString(url))) goto error;
+  }
   
   rc = TRUE;
 error:
