@@ -5,7 +5,7 @@
  * Archive producer interface
 
  MediaTex is an Electronic Archives Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -48,8 +48,9 @@ struct Archive
   RG*        fromContainers; // (FromAsso*)
   Container* toContainer;    // only one: (choose a rule TGZ or TAR+GZ)
   time_t     uploadTime;     // uploaded archive (from INC container)
-  float      extractScore;   // computed value used by cache
+  char*      imgExtractionPath; // image extraction path (from IMG container)
   int        incInherency;   // is a new incoming (even by inherency)
+  float      extractScore;   // computed value used by cache
 
   // documentTree related data
   RG* documents;
@@ -75,7 +76,6 @@ int cmpArchiveAvl(const void *p1, const void *p2);
 int cmpArchiveScore(const void *p1, const void *p2);
 Archive* getArchive(Collection* coll, char* hash, off_t size);
 Archive* addArchive(Collection* coll, char* hash, off_t size);
-int delArchive(Collection* coll, Archive* archive);
 
 /* Private */
 Archive* createArchive(void);
