@@ -5,7 +5,7 @@
  * Manage local cache directory and DB
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -711,7 +711,8 @@ int cleanCacheTree(Collection* coll)
       break;
       
     default:
-      logMemory(LOG_ERR, "cannot unindex %s record", strRecordType(record));
+      logMemory(LOG_ERR, "cannot unindex %s record",
+		strRecordType(record));
       goto error2;
     }
 
