@@ -5,7 +5,7 @@
  * Extraction producer interface
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@ strEType(EType self)
 {
 
   static char* typeLabels[ETYPE_MAX] =
-    {"UNDEF", 
-     "INC", "ISO", "CAT", 
+    {"UNDEF", "INC", "IMG",
+     "ISO", "CAT", 
      "TGZ", "TBZ", "AFIO",
      "TAR", "CPIO", 
      "GZIP", "BZIP",
@@ -195,7 +195,6 @@ destroyContainer(Container* self)
   return (Container*)0;
 }
 
-
 /*=======================================================================
  * Function   : serializeContainer
  * Description: Serialize a Container.
@@ -220,24 +219,16 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
   }
 
   if (avl_count(self->childs) < 1) {
-    if (self->type != INC) {
-      fd->print(fd, "\n#(%s\n", strEType(self->type));
-      fd->print(fd, "#=>\n");
-      fd->print(fd, "#)\n");
-      goto end;
-    }
-    else {
-      /* not blocking but prefer to stop now */
-      logMemory(LOG_CRIT, "empty container to serialize !");
-      goto error;
-    }
+    // not blocking but we prefer to stop now
+    logMemory(LOG_CRIT, "do not serialize an empty container!");
+    goto error;
   }
 
   fd->print(fd, "\n(%s\n", strEType(self->type));
   fd->doCut = FALSE;
  
-  // serialise parents (only INC container doesn't have parent)
-  if (self->type != INC) {
+  // serialise parents (only INC and IMG container doesn't have parent)
+  if (self->type != INC && self->type != IMG) {
     rgRewind(self->parents);
     if ((archive = rgNext(self->parents)) == 0) goto error;
     do {
@@ -252,14 +243,19 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
 
     for (node = self->childs->head; node; node = node->next) {
       asso = node->item;
+
+      // remove safe incoming
       if (self->type == INC && !isIncoming(coll, asso->archive)) continue;
+
+      // remove image extraction path whan available from another rule
+      if (self->type == IMG && asso->archive->fromContainers->nbItems > 0) continue;
+      
       if (!serializeExtractRecord(asso->archive, fd)) goto error;
       fd->print(fd, "\t%s\n", asso->path);
     }
   }
 
   fd->print(fd, ")\n");
- end:
   fd->doCut = TRUE;
   ++env.progBar.cur;
   rc = TRUE;
@@ -345,8 +341,12 @@ createExtractTree(void)
     goto error;
 
   // special INC container for newly uploaded files
-  if (!(rc->incoming = createContainer())) goto error;
-  rc->incoming->type = INC;
+  if (!(rc->inc = createContainer())) goto error;
+  rc->inc->type = INC;
+
+  // special IMG container to reminds supports paths
+  if (!(rc->img = createContainer())) goto error;
+  rc->img->type = IMG;
 
   rc->score = -1;
 
@@ -370,7 +370,8 @@ destroyExtractTree(ExtractTree* self)
   if (!self) goto error;
 
   avl_free_tree(self->containers);
-  self->incoming = destroyContainer(self->incoming);
+  self->inc = destroyContainer(self->inc);
+  self->img = destroyContainer(self->img);
 
   free(self);
 
@@ -425,8 +426,13 @@ serializeExtractTree(Collection* coll, CvsFile* fd)
   //fd->print(fd, "# Version: $" "Id" "$\n");
 
   // serialize INC container if not empty
-  if (avl_count(self->incoming->childs) > 0) {
-    if (!serializeContainer(coll, self->incoming, fd)) goto error;
+  if (avl_count(self->inc->childs) > 0) {
+    if (!serializeContainer(coll, self->inc, fd)) goto error;
+  }
+
+  // serialize IMG container if not empty
+  if (avl_count(self->img->childs) > 0) {
+    if (!serializeContainer(coll, self->img, fd)) goto error;
   }
 
   // serialize all other containers
@@ -467,14 +473,15 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "addFromArchive %s/%s:%lli -> %s:%lli",
 	    strEType(container->type), 
-	    container->type == INC?"-":container->parent->hash,
-	    container->type == INC?0:
-	    (long long int)container->parent->size,
+	    container->type == INC || container->type == IMG?
+	    "-":container->parent->hash,
+	    container->type == INC || container->type == IMG?
+	    0:(long long int)container->parent->size,
 	    archive->hash, (long long int)archive->size);
 
-  if (container->type == INC) {
-    logMemory(LOG_ERR, 
-	      "INC container cannot have parent");
+  if (container->type == INC || container->type == IMG) {
+    logMemory(LOG_ERR, "%s container cannot have parent",
+	      strEType(container->type));
     goto error;
   }
   
@@ -550,11 +557,18 @@ delFromArchive(Collection* coll, Container* container, Archive* archive)
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "delFromArchive %s/%s:%lli -> %s:%lli",
 	    strEType(container->type), 
-	    container->type == INC?"-":container->parent->hash,
-	    container->type == INC?0:
-	    (long long int)container->parent->size,
+	    container->type == INC || container->type == IMG?
+	    "-":container->parent->hash,
+	    container->type == INC || container->type == IMG?
+	    0:(long long int)container->parent->size,
 	    archive->hash, (long long int)archive->size);
 
+  if (container->type == INC || container->type == IMG) {
+    logMemory(LOG_ERR, "%s container cannot have parent",
+	      strEType(container->type));
+    goto error;
+  }
+
   // del archive to container's parents ring
   if ((curr = rgHaveItem(container->parents, archive))) {
     rgRemove_r(container->parents, &curr);
@@ -576,9 +590,39 @@ delFromArchive(Collection* coll, Container* container, Archive* archive)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : getFromAsso
+ * Description: Search a fromAsso into a Container
+ * Synopsis   : fromAsso* getFromAsso(Container* container, 
+ *                                    Archive* parent)
+ * Input      : Container* container: where to find
+ *              Archive* archive: content to find 
+ * Output     : The address of the fromAsso.
+ =======================================================================*/
+FromAsso* 
+getFromAsso(Container* container, Archive* archive)
+{
+  FromAsso* rc = 0;
+  FromAsso asso;
+  AVLNode* node = 0;
+
+  checkContainer(container);
+  checkArchive(archive);
+  logMemory(LOG_DEBUG, "%s", "getFromAsso");
+
+  // look for fromAsso
+  asso.archive = archive;
+  asso.container = container;
+  if ((node = avl_search(container->childs, &asso))) {
+    rc = (FromAsso*)node->item;
+  }
+ error:
+  return rc;
+}
+
 /*=======================================================================
  * Function   : addFromAsso
- * Description: Add a fromAsso if not already there
+ * Description: Add a fromAsso if not already into this container
  * Synopsis   : FromAsso* addFromAsso(Collection* coll, Archive* archive
  *                                    Container* container)
  * Input      : Collection* coll : where to add
@@ -586,8 +630,7 @@ delFromArchive(Collection* coll, Container* container, Archive* archive)
  *              Container* container : id
  *              char* path : path to file into the container
  * Output     : FromAsso* : the FromAsso we have found/added
- * Note       : archive from container may have multiple instances
- *              (as an archive may comes from severals containers)
+ * Note       : as an archive may comes from severals containers
  =======================================================================*/
 FromAsso* 
 addFromAsso(Collection* coll, Archive* archive, Container* container,
@@ -604,9 +647,10 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   logMemory(LOG_DEBUG, "addFromAsso %s:%lli -> %s/%s:%lli",
 	    archive->hash, (long long int)archive->size,
 	    strEType(container->type), 
-	    container->type == INC?"-":container->parent->hash,
-	    container->type == INC?0:
-	    (long long int)container->parent->size);
+	    container->type == INC || container->type == IMG?
+	    "-":container->parent->hash,
+	    container->type == INC || container->type == IMG?
+	    0:(long long int)container->parent->size);
 
   switch (container->type) {
   case GZIP:
@@ -619,7 +663,7 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
     break;
 
   case INC:
-    // having 1 inc asso and 1 normal asso => remove the inc asso
+    // having 1 INC asso and 1 normal asso => remove the INC asso
     if (archive->fromContainers->nbItems > 0) {
       logMemory(LOG_NOTICE, 
 		"%s:%lli file is now archived (no more an incoming)",
@@ -645,8 +689,25 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
     if (!archive->uploadTime || archive->uploadTime > time) {
       archive->uploadTime = time;
     }
-
     break;
+    
+  case IMG:
+    // if IMG asso is already, check it match the current's one
+    if ((asso = getFromAsso(container, archive))) {
+      if (strcmp(asso->path, path)) {
+	logMemory(LOG_ERR,
+		  "cannot add several IMG asso with different paths"
+		  " (%s:%lli)",
+		  archive->hash, (long long int)archive->size);
+	asso = 0;
+	goto error;
+      }
+
+      // ignore new IMG asso that match the current's one
+      goto end;
+    }
+    break;
+    
   default:
     // having 1 inc asso and 1 normal asso => remove the inc asso
     if (archive->uploadTime) {
@@ -665,13 +726,27 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   asso->container = container;
   asso->path = string;
 
-  // incomings do not provides extraction path
-  if (container->type != INC) {
+  switch (container->type) {
+  case INC:
+    break;
+  case IMG:
+    archive->imgExtractionPath = string;
+    break;
+  default:
+    // INC and IMG asso are already linked to archive
     if (!rgInsert(archive->fromContainers, asso)) goto error;
   }
+
+  // only provide archives once by container
   if (!avl_insert(container->childs, asso)) {
-    logMemory(LOG_ERR, "cannot add %s:%lli (already there?)",
-	      archive->hash, (long long int)archive->size);
+    if (errno != EEXIST) {
+      logMemory(LOG_ERR, "fails to add add %s:%lli content",
+		archive->hash, (long long int)archive->size);
+    }
+    else {
+      logMemory(LOG_ERR, "cannot add %s:%lli (already there)",
+		archive->hash, (long long int)archive->size);
+    }
     goto error;
   }
  end:
@@ -686,7 +761,7 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
 
 /*=======================================================================
  * Function   : delFromAsso
- * Description: Del an fromAsso if not already there
+ * Description: Del a fromAsso
  * Synopsis   : void delFromAsso(Collection* coll, FromAsso* self)
  * Input      : Collection* coll: where to del
  *              FromAsso* self: association to del
@@ -703,16 +778,20 @@ delFromAsso(Collection* coll, FromAsso* self)
   logMemory(LOG_DEBUG, "delFromAsso %s:%lli -> %s/%s:%lli",
 	    self->archive->hash, (long long int)self->archive->size,
 	    strEType(self->container->type), 
-	    self->container->type == INC?"-":self->container->parent->hash,
-	    self->container->type == INC?0:
-	    (long long int)self->container->parent->size);
+	    self->container->type == INC || self->container->type == IMG?
+	    "-":self->container->parent->hash,
+	    self->container->type == INC || self->container->type == IMG?
+	    0:(long long int)self->container->parent->size);
 
-  // incomings do not provides extraction path
-  if (self->container->type == INC) {
+  // unlink asso from archive
+  switch (self->container->type) {
+  case IMG:
+    self->archive->imgExtractionPath = 0;
+    break;
+  case INC:
     self->archive->uploadTime = 0;
-  }
-  else {
-    // delete asso from archive
+    break;
+  default:
     if ((curr = rgHaveItem(self->archive->fromContainers, self))) {
       rgRemove_r(self->archive->fromContainers, &curr);
     }
@@ -731,11 +810,11 @@ delFromAsso(Collection* coll, FromAsso* self)
 
 /*=======================================================================
  * Function   : getContainer
- * Description: Search or may create a Container
+ * Description: Search a Container
  * Synopsis   : Container* getContainer(Collection* coll, 
  *                                        EType type, Archive* parent)
  * Input      : Collection* coll: where to find
- *              EType type : first id
+ *              EType type: first id
  *              Archive* parent : second id
  * Output     : The address of the Container.
  =======================================================================*/
@@ -781,8 +860,9 @@ addContainer(Collection* coll, EType type, Archive* parent)
   checkArchive(parent);
   logMemory(LOG_DEBUG, "addContainer %s", strEType(type));
 
-  if (type == INC) {
-    logMemory(LOG_ERR, "INC container always exists and cannot be add");
+  if (type == INC || type == IMG) {
+    logMemory(LOG_ERR, "%s internal container cannot be add",
+	      strEType(type));
     goto error;
   }
 
@@ -799,10 +879,16 @@ addContainer(Collection* coll, EType type, Archive* parent)
   container->parent = parent;
   if (!addFromArchive(coll, container, parent)) goto error;
   if (!avl_insert(coll->extractTree->containers, container)) {
-    logMemory(LOG_ERR, "cannot add container (already there?)");
+    if (errno != EEXIST) {
+      logMemory(LOG_ERR, "fails to add %s container", strEType(type))
+    }
+    else {
+      logMemory(LOG_ERR, "cannot add %i container (already there)",
+		strEType(type))
+    }
     goto error;
   }
-
+  
   rc = container;
  error:
   if (!rc) {
@@ -832,9 +918,10 @@ delContainer(Collection* coll, Container* self)
   if (!self) goto error;
   logMemory(LOG_DEBUG, "delContainer %s/%s:%lli", 
 	    strEType(self->type), 
-	    self->type == INC?"-":self->parent->hash,
-	    self->type == INC?0:
-	    (long long int)self->parent->size);
+	    self->type == INC || self->type == IMG?
+	    "-":self->parent->hash,
+	    self->type == INC || self->type == IMG?
+	    0:(long long int)self->parent->size);
 
   // delete content associations to archives
   while ((node = self->childs->head)) {
@@ -842,10 +929,11 @@ delContainer(Collection* coll, Container* self)
   }
 
   // delete container link with archives
+  // (INC and IMG do not had parent)
   while ((arch = rgHead(self->parents))) {
     arch->toContainer = 0;
     rgRemove(self->parents);
-  }
+  } 
 
   // delete container from extract tree and free it
   avl_delete(coll->extractTree->containers, self);
@@ -873,7 +961,8 @@ diseaseExtractTree(Collection* coll)
   logMemory(LOG_DEBUG, "diseaseExtractTree %s", coll);
 
   // diseases containers
-  if (!delContainer(coll, coll->extractTree->incoming)) goto error;
+  if (!delContainer(coll, coll->extractTree->inc)) goto error;
+  if (!delContainer(coll, coll->extractTree->img)) goto error;
   while ((node = coll->extractTree->containers->head))
     if (!delContainer(coll, node->item)) goto error;
 
