@@ -5,7 +5,7 @@
  * Extraction producer interface
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 // Container types
 typedef enum {UNDEF=0, 
 	      INC,             // for uploads not already burned
+	      IMG,             // tips to remind supports extraction path
 	      ISO,             // CD image
 	      CAT,             // generic way to do multi-volume
 	      TGZ, TBZ, AFIO,  // GNU/Linux agregation + compression
@@ -62,7 +63,10 @@ struct Container {
 
 struct ExtractTree {
   AVLTree* containers;
-  Container* incoming;   // special container with no parent
+
+  // special container with no parents
+  Container* inc;        // provides unsafe incomings
+  Container* img;        // provides top image extraction's path
 
   float score;           // global score for the collection
 };
