@@ -5,7 +5,7 @@
 * Server producer interface
 
 MediaTex is an Electronic Records Management System
-Copyright (C) 2014 2015 2016 Nicolas Roche
+Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -416,6 +416,8 @@ ServerTree*
 destroyServerTree(ServerTree* self)
 {
   if(self == 0) goto error;
+  self->dnsUrl = destroyString(self->dnsUrl);
+  
   // do not delete archives objets 
   self->archives = destroyOnlyRing(self->archives);
   self->servers = destroyRing(self->servers, 
@@ -482,7 +484,10 @@ serializeServerTree(Collection* coll)
 	    self->master->sshPort);
     fprintf(fd, "%-10s %s\n", "master", self->master->fingerPrint);
   }
-  
+
+  if (*self->dnsHost) {
+    fprintf(fd, "%-10s %s\n", "dnsHost", self->dnsHost);
+  }
   fprintf(fd, "%-10s %s\n", "collKey", self->aesKey);
   fprintf(fd, "%-10s %s\n", "https", self->doHttps?"yes":"no");
   
@@ -642,7 +647,7 @@ delImage(Collection* coll, Image* image)
   }
 
   // delete image from archive
-  if ((curr = rgHaveItem(image->archive->images, image->archive))) {
+  if ((curr = rgHaveItem(image->archive->images, image))) {
     rgRemove_r(image->archive->images, &curr);
   }
 
