@@ -81,11 +81,12 @@ extern int conf_debug;
     confAROBASE = 283,
     confMINUS = 284,
     confENDBLOCK = 285,
-    confSTRING = 286,
-    confNUMBER = 287,
-    confSCORE = 288,
-    confSIZE = 289,
-    confTIME = 290
+    confMOTDPOLICY = 286,
+    confSTRING = 287,
+    confNUMBER = 288,
+    confSCORE = 289,
+    confSIZE = 290,
+    confTIME = 291
   };
 #endif
 /* Tokens.  */
@@ -117,11 +118,12 @@ extern int conf_debug;
 #define confAROBASE 283
 #define confMINUS 284
 #define confENDBLOCK 285
-#define confSTRING 286
-#define confNUMBER 287
-#define confSCORE 288
-#define confSIZE 289
-#define confTIME 290
+#define confMOTDPOLICY 286
+#define confSTRING 287
+#define confNUMBER 288
+#define confSCORE 289
+#define confSIZE 290
+#define confTIME 291
 
 /* Value type.  */
 #if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED
@@ -136,7 +138,7 @@ union CONF_STYPE
   off_t         size;
   time_t        time;
 
-#line 140 "parser/confFile.tab.h" /* yacc.c:1909  */
+#line 142 "parser/confFile.tab.h" /* yacc.c:1909  */
 };
 # define CONF_STYPE_IS_TRIVIAL 1
 # define CONF_STYPE_IS_DECLARED 1
@@ -156,7 +158,7 @@ int conf_parse (yyscan_t yyscanner, Collection* coll);
  * configuation file parser
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -174,6 +176,6 @@ int conf_parse (yyscan_t yyscanner, Collection* coll);
 
 #define YYSTYPE CONF_STYPE
 
-#line 178 "parser/confFile.tab.h" /* yacc.c:1909  */
+#line 180 "parser/confFile.tab.h" /* yacc.c:1909  */
 
 #endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */
