@@ -177,7 +177,7 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
  * extract parser.
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
    
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -509,8 +509,8 @@ static const yytype_uint8 yytranslate[] =
 static const yytype_uint8 yyrline[] =
 {
        0,   110,   110,   112,   118,   122,   128,   136,   137,   138,
-     145,   157,   170,   174,   180,   182,   191,   195,   201,   208,
-     215
+     144,   162,   175,   179,   185,   187,   196,   200,   206,   213,
+     220
 };
 #endif
 
@@ -522,7 +522,7 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "extrERROR", "extrOPEN", "extrCLOSE",
   "extrTYPE", "extrIMPLIES", "extrAS", "extrHASH", "extrCOLON", "extrSIZE",
   "extrCOMMA", "extrSTRING", "$accept", "file", "stanzas", "stanza",
-  "container", "incContainer", "stdContainer", "parents", "childs",
+  "container", "orphaneContainer", "stdContainer", "parents", "childs",
   "childs2", "parent", "child", "archive", YY_NULLPTR
 };
 #endif
@@ -1347,108 +1347,114 @@ yyreduce:
     break;
 
   case 10:
-#line 146 "parser/extractFile.y" /* yacc.c:1646  */
+#line 145 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: incContainer: %s", 
+  logParser(LOG_DEBUG, "line %i: orphaneContainer: %s", 
 	    LINENO, strEType((yyvsp[0].type)));
-  if ((yyvsp[0].type) != INC) {
+  switch ((yyvsp[0].type)) {
+  case INC:
+    container = coll->extractTree->inc;
+    break;
+  case IMG:
+    container = coll->extractTree->img;
+    break;
+  default:
     logParser(LOG_ERR, "line %i: %s", LINENO, 
-	      "only the 'INC' container do not provide parent");
+	      "only 'INC' or 'IMG' containers do not provide parent");
     YYERROR;
   }
-  container = coll->extractTree->incoming;
 }
-#line 1362 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1368 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 158 "parser/extractFile.y" /* yacc.c:1646  */
+#line 163 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
 	    LINENO, strEType((yyvsp[-1].type)));
-  if ((yyvsp[-1].type) == INC) {
+  if ((yyvsp[-1].type) == INC || (yyvsp[-1].type) == IMG) {
     logParser(LOG_ERR, "line %i: %s (%s)", LINENO, 
-	      "the 'INC' container cannot have parent");
+	      "'INC' and 'IMG' containers cannot have parent");
     YYERROR;
   }
   if (!(container = addContainer(coll, (yyvsp[-1].type), (yyvsp[0].archive)))) YYERROR;
 }
-#line 1377 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1383 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 171 "parser/extractFile.y" /* yacc.c:1646  */
+#line 176 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
 }
-#line 1385 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1391 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 175 "parser/extractFile.y" /* yacc.c:1646  */
+#line 180 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
 }
-#line 1393 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1399 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 182 "parser/extractFile.y" /* yacc.c:1646  */
+#line 187 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  if (container->type != INC) {
+  if (container->type != INC && container->type != IMG) {
     logParser(LOG_ERR, "line %i: %s", LINENO, 
-	      "only the 'INC' container may do not provide childs");
+	      "only 'INC' or 'IMG' containers may do not provide childs");
     YYERROR;
   }
 }
-#line 1405 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1411 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 192 "parser/extractFile.y" /* yacc.c:1646  */
+#line 197 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
 }
-#line 1413 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1419 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 196 "parser/extractFile.y" /* yacc.c:1646  */
+#line 201 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
 }
-#line 1421 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1427 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 202 "parser/extractFile.y" /* yacc.c:1646  */
+#line 207 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parent: archive", LINENO);
   if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
 }
-#line 1430 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1436 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 209 "parser/extractFile.y" /* yacc.c:1646  */
+#line 214 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: child: archive %s", LINENO, (yyvsp[0].string));
   if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
 }
-#line 1439 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1445 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 216 "parser/extractFile.y" /* yacc.c:1646  */
+#line 221 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = addArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) YYERROR;
 }
-#line 1448 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1454 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1452 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1458 "parser/extractFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1676,7 +1682,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 222 "parser/extractFile.y" /* yacc.c:1906  */
+#line 227 "parser/extractFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
