@@ -68,35 +68,36 @@ extern int serv_debug;
     servMDTXPORT = 270,
     servSSHPORT = 271,
     servWWWPORT = 272,
-    servCOLLKEY = 273,
-    servUSERKEY = 274,
-    servHOSTKEY = 275,
-    servPROVIDE = 276,
-    servCOMMA = 277,
-    servCOLON = 278,
-    servEQUAL = 279,
-    servENDBLOCK = 280,
-    servCACHESIZE = 281,
-    servCACHETTL = 282,
-    servQUERYTTL = 283,
-    servSUPPTTL = 284,
-    servUPLOADTTL = 285,
-    servSERVERTTL = 286,
-    servMAXSCORE = 287,
-    servBADSCORE = 288,
-    servPOWSUPP = 289,
-    servFACTSUPP = 290,
-    servFILESCORE = 291,
-    servMINGEODUP = 292,
-    servERROR = 293,
-    servSTRING = 294,
-    servNUMBER = 295,
-    servSCORE = 296,
-    servHASH = 297,
-    servSIZE = 298,
-    servTIME = 299,
-    servDATE = 300,
-    servBOOLEAN = 301
+    servDNSHOST = 273,
+    servCOLLKEY = 274,
+    servUSERKEY = 275,
+    servHOSTKEY = 276,
+    servPROVIDE = 277,
+    servCOMMA = 278,
+    servCOLON = 279,
+    servEQUAL = 280,
+    servENDBLOCK = 281,
+    servCACHESIZE = 282,
+    servCACHETTL = 283,
+    servQUERYTTL = 284,
+    servSUPPTTL = 285,
+    servUPLOADTTL = 286,
+    servSERVERTTL = 287,
+    servMAXSCORE = 288,
+    servBADSCORE = 289,
+    servPOWSUPP = 290,
+    servFACTSUPP = 291,
+    servFILESCORE = 292,
+    servMINGEODUP = 293,
+    servERROR = 294,
+    servSTRING = 295,
+    servNUMBER = 296,
+    servSCORE = 297,
+    servHASH = 298,
+    servSIZE = 299,
+    servTIME = 300,
+    servDATE = 301,
+    servBOOLEAN = 302
   };
 #endif
 /* Tokens.  */
@@ -115,35 +116,36 @@ extern int serv_debug;
 #define servMDTXPORT 270
 #define servSSHPORT 271
 #define servWWWPORT 272
-#define servCOLLKEY 273
-#define servUSERKEY 274
-#define servHOSTKEY 275
-#define servPROVIDE 276
-#define servCOMMA 277
-#define servCOLON 278
-#define servEQUAL 279
-#define servENDBLOCK 280
-#define servCACHESIZE 281
-#define servCACHETTL 282
-#define servQUERYTTL 283
-#define servSUPPTTL 284
-#define servUPLOADTTL 285
-#define servSERVERTTL 286
-#define servMAXSCORE 287
-#define servBADSCORE 288
-#define servPOWSUPP 289
-#define servFACTSUPP 290
-#define servFILESCORE 291
-#define servMINGEODUP 292
-#define servERROR 293
-#define servSTRING 294
-#define servNUMBER 295
-#define servSCORE 296
-#define servHASH 297
-#define servSIZE 298
-#define servTIME 299
-#define servDATE 300
-#define servBOOLEAN 301
+#define servDNSHOST 273
+#define servCOLLKEY 274
+#define servUSERKEY 275
+#define servHOSTKEY 276
+#define servPROVIDE 277
+#define servCOMMA 278
+#define servCOLON 279
+#define servEQUAL 280
+#define servENDBLOCK 281
+#define servCACHESIZE 282
+#define servCACHETTL 283
+#define servQUERYTTL 284
+#define servSUPPTTL 285
+#define servUPLOADTTL 286
+#define servSERVERTTL 287
+#define servMAXSCORE 288
+#define servBADSCORE 289
+#define servPOWSUPP 290
+#define servFACTSUPP 291
+#define servFILESCORE 292
+#define servMINGEODUP 293
+#define servERROR 294
+#define servSTRING 295
+#define servNUMBER 296
+#define servSCORE 297
+#define servHASH 298
+#define servSIZE 299
+#define servTIME 300
+#define servDATE 301
+#define servBOOLEAN 302
 
 /* Value type.  */
 #if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED
@@ -160,7 +162,7 @@ union SERV_STYPE
   char   string[(MAX_SIZE_STRING+1)*2]; // keys needs more place
   char   hash[MAX_SIZE_MD5+1];
 
-#line 164 "parser/serverFile.tab.h" /* yacc.c:1909  */
+#line 166 "parser/serverFile.tab.h" /* yacc.c:1909  */
 };
 # define SERV_STYPE_IS_TRIVIAL 1
 # define SERV_STYPE_IS_DECLARED 1
@@ -180,7 +182,7 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
  * server file parser
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -198,6 +200,6 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 
 #define YYSTYPE SERV_STYPE
 
-#line 202 "parser/serverFile.tab.h" /* yacc.c:1909  */
+#line 204 "parser/serverFile.tab.h" /* yacc.c:1909  */
 
 #endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */
