@@ -5,7 +5,7 @@
  * Manage local cache directory and DB
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 2016 Nicolas Roche
+ Copyright (C) 2014 2015 2016 2017 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -90,26 +90,34 @@ getFinalSupplyInPath(char* extra)
   }
   return rc;
 }
+
 /*=======================================================================
  * Function   : getFinalSupplyOutPath
  * Description: remove ending ':supportName' if there
- * Synopsis   : char* getFinalSupplyOutPath(char* extra) 
- * Input      : char* extra = the extra record's attribute
+ * Synopsis   : char* getFinalSupplyOutPath(Collection* coll, 
+ *                                          Record* record) 
+ * Input      : Collection* coll 
+ *              Record* record: the input record to work on
  * Output     : Allocated string based on second part or NULL on failure
  =======================================================================*/
 char*
-getFinalSupplyOutPath(char* extra) 
+getFinalSupplyOutPath(Collection* coll, Record* record) 
 {
   char* rc = 0;
+  char* extra = 0;
   char* ptrOut = 0;
   char* ptrColon = 0;
   char* ptrPart2 = 0;
   char* ptrFilename = 0;
   char car = 0;
 
-  checkLabel(extra);
+  checkCollection(coll);
+  checkRecord(record);
   logMain(LOG_DEBUG, "getFinalSupplyOutPath %s", extra);
-
+  extra = record->extra;
+  checkLabel(extra);
+  checkArchive(record->archive);
+  
   // look for ':' that limit part1 and part2, if there
   for (ptrColon=extra; *ptrColon && *ptrColon != ':'; ++ptrColon);
 
@@ -120,6 +128,12 @@ getFinalSupplyOutPath(char* extra)
   car = *ptrColon;
   *ptrColon = 0;
 
+  // look if an IMG rule matchs
+  if (record->archive->imgExtractionPath) {
+    if (!(ptrOut = createString(record->archive->imgExtractionPath))) goto error;
+    goto end;
+  }
+  
   // set output to "PART2"
   if (!isEmptyString(ptrPart2)) {
     if (!(ptrOut = createString(ptrPart2))) goto error;
@@ -137,6 +151,7 @@ getFinalSupplyOutPath(char* extra)
     if (!(ptrOut = catString(ptrOut, ptrFilename+1))) goto error;
   }
 
+ end:
   rc = ptrOut;
   ptrOut = 0;
  error:
